# encoding: utf-8

# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	clients/novell-dhcp.ycp
# Package:	Configuration of novell-dhcp
# Summary:	Main file
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: novell-dhcp.ycp 27914 2006-02-13 14:32:08Z locilka $
#
# Main file for novell-dhcp configuration. Uses all other files.
module Yast
  class NovellDhcpClient < Client
    def main
      Yast.import "UI"

      #**
      # <h3>Configuration of novell-dhcp</h3>

      textdomain "novell-dhcp"

      # The main ()
      Builtins.y2milestone("----------------------------------------")
      Builtins.y2milestone("NovellDhcp module started")

      Yast.import "Progress"
      Yast.import "Report"
      Yast.import "Summary"
      Yast.import "NovellAddonInstall"
      Yast.import "CommandLine"
      Yast.include self, "novell-dhcp/wizards.rb"

      @cmdline_description = {
        "id"         => "novell-dhcp",
        # Command line help text for the Xnovell-dhcp module
        "help"       => _(
          "Configuration of Novell DHCP Services"
        ),
        "guihandler" => fun_ref(method(:NovellDhcpSequence), "any ()"),
        "initialize" => fun_ref(NovellDhcp.method(:Read), "boolean ()"),
        "finish"     => fun_ref(NovellDhcp.method(:Write), "boolean ()"),
        "actions" =>
          # FIXME TODO: fill the functionality description here
          {},
        "options" =>
          # FIXME TODO: fill the option descriptions here
          {},
        "mappings" =>
          # FIXME TODO: fill the mappings of actions and options here
          {}
      }

      # is this proposal or not?
      @propose = false
      @args = WFM.Args
      if Ops.greater_than(Builtins.size(@args), 0)
        if Ops.is_path?(WFM.Args(0)) && WFM.Args(0) == path(".propose")
          Builtins.y2milestone("Using PROPOSE mode")
          @propose = true
        end
      end

      # main ui function
      @ret = nil

      if @propose
        if Ops.get(
            NovellAddonInstall.products_to_configure,
            "novell-dhcp",
            true
          )
          @ret = NovellDhcpAutoSequence()
        else
          @ret = :next
        end
      else
        @ret = CommandLine.Run(@cmdline_description)
      end
      Builtins.y2debug("ret=%1", @ret)

      # Finish
      Builtins.y2milestone("NovellDhcp module finished")
      Builtins.y2milestone("----------------------------------------")

      deep_copy(@ret) 

      # EOF
    end
  end
end

Yast::NovellDhcpClient.new.main
