# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-dhcp/complex.ycp
# Package:	Configuration of novell-dhcp
# Summary:	Dialogs definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: complex.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellDhcpComplexInclude
    def initialize_novell_dhcp_complex(include_target)
      Yast.import "UI"

      textdomain "novell-dhcp"

      Yast.import "Label"
      Yast.import "Popup"
      Yast.import "Wizard"
      Yast.import "UIHelper"
      Yast.import "NovellDhcp"

      Yast.include include_target, "novell-dhcp/helps.rb"
    end

    # Return a modification status
    # @return true if data was modified
    def Modified
      NovellDhcp.Modified
    end

    def ReallyAbort
      !NovellDhcp.Modified || Popup.ReallyAbort(true)
    end

    def PollAbort
      UI.PollInput == :abort
    end

    # Read settings dialog
    # @return `abort if aborted and `next otherwise
    def ReadDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "read", ""))
      # NovellDhcp::AbortFunction = PollAbort;
      ret = NovellDhcp.Read
      ret ? :next : :abort
    end

    # Write settings dialog
    # @return `abort if aborted and `next otherwise
    def WriteDialog
      Wizard.RestoreHelp(Ops.get_string(@HELPS, "write", ""))
      # NovellDhcp::AbortFunction = PollAbort;
      ret = NovellDhcp.Write
      ret ? :next : :abort
    end

    # Summary dialog
    # @return dialog result
    def SummaryDialog
      # NovellDhcp summary dialog caption
      caption = _("OES DHCP Services Configuration")

      # FIXME
      summary = NovellDhcp.Summary
      unconfigured = Ops.get_list(summary, 1, [])
      configured = Ops.get_string(summary, 0, "")

      # Frame label
      #    term contents = Wizard_hw::DetectedContent(_("Novell Dhcp Services to Configure"),
      #	    unconfigured, false, configured);
      contents = nil

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "summary", ""),
        Label.BackButton,
        Label.FinishButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel || ret == :back
          if ReallyAbort()
            break
          else
            next
          end
        # overview dialog
        elsif ret == :edit_button
          ret = :overview
          break
        # configure the selected device
        elsif ret == :configure_button
          # TODO FIXME: check for change of the configuration
          selected = UI.QueryWidget(Id(:detected_selbox), :CurrentItem)
          if selected == :other
            ret = :other
          else
            ret = :configure
          end
          break
        elsif ret == :next
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end

    # Overview dialog
    # @return dialog result
    def OverviewDialog
      # NovellDhcp overview dialog caption
      caption = _("OES DHCP Services Overview")

      overview = NovellDhcp.Overview

      # FIXME table header
      contents = UIHelper.EditTable(
        # Table header
        Header(_("Number"), _("OESDhcp")),
        overview,
        nil,
        nil,
        nil,
        nil
      )

      contents = UIHelper.SpacingAround(contents, 1.5, 1.5, 1.0, 1.0)

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "overview", ""),
        Label.BackButton,
        Label.FinishButton
      )

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        # add
        elsif ret == :add_button
          # FIXME
          ret = :add
          break
        # edit
        elsif ret == :edit_button
          # FIXME
          ret = :edit
          break
        # delete
        elsif ret == :delete_button
          # FIXME
          next
        elsif ret == :next || ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end

      deep_copy(ret)
    end
  end
end
