# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2022 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-dhcp/dialogs.ycp
# Package:	Configuration of novell-dhcp
# Summary:	Dialogs definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: dialogs.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellDhcpDialogsInclude
    def initialize_novell_dhcp_dialogs(include_target)
      Yast.import "UI"

      textdomain "novell-dhcp"

      Yast.import "Label"
      Yast.import "Wizard"
      Yast.import "Popup"
      Yast.import "Report"
      Yast.import "NovellDhcp"
      Yast.import "NovellLDAP"
      Yast.import "NovellLDAPUI"
      Yast.import "NovellUtils"
      Yast.import "NovellValidators"
      Yast.import "NetworkInterfaces"
      Yast.import "IP"
      Yast.import "Address"

      Yast.include include_target, "novell-dhcp/complex.rb"
      Yast.include include_target, "novell-dhcp/helps.rb"

      # Currently selected item in the interface table
      @current_item_iface = nil
    end

    def PromptIfNeededForEdirAdminPassword
      useXad = false

      if NovellDhcp.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          useXad = true
        end # if this value is set at all, then it is the eDir admin (in spite of xad name)
      end
      Builtins.y2milestone(
        "NovellDhcp.PromptIfNeededForEdirAdminPassword:use xad:%1",
        useXad
      )

      if useXad
        if Ops.get_string(NovellLDAP.Settings, "XAD_TREE_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.XadTreeAdminPasswordDialog
        end
      else
        if Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_PASSWORD", "") == ""
          NovellLDAPUI.AdminPasswordDialog
        end
      end
      Builtins.y2milestone(
        "NovellDhcp.PromptIfNeededForEdirAdminPassword:useXad %1",
        useXad
      )
      useXad
    end

    # Novelldhcp2 dialog
    # @return dialog result
    def Novelldhcp2Dialog
      if NovellDhcp.upgradeMode
        Popup.Message(NovellUtils.noConfigMessage)
        Builtins.y2milestone(
          "NovellDhcp.NovellDhcp2Dialog:skipping GUI since we are in upgrade mode."
        )
        return :skip
      end

      # Novell DHCP Services configure2 dialog caption
      caption = _("OES DHCP Services Configuration")

      server_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDhcp.Settings, "CONFIG_DHCPSRV_SERVER_CONTEXT", "")
      )
      locator_context = NovellUtils.Nds2Ldap(
        Ops.get_string(
          NovellDhcp.Settings,
          "CONFIG_DHCPSRV_LOCATOR_CONTEXT",
          ""
        )
      )
      group_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellDhcp.Settings, "CONFIG_DHCPSRV_GROUP_CONTEXT", "")
      )
      object_name = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_SERVER_OBJECT_NAME",
        ""
      )
      debug_path = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_DEBUGFILE",
        ""
      )
      ldap_method = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_METHOD",
        ""
      )
      chase_referrals = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_REFERRALS",
        ""
      )
      get_context_from_existing = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCP_GET_CONTEXT_FROM_EXISTING",
        "no"
      )
      ndsTreeType = NovellDhcp.GetTreeType

      contents = HVSquash(
        VBox(
          TextEntry(
            Id(:server_context),
            _("DHCP Server context (e.g. ou=servers,o=microfocus)"),
            server_context
          ),
          TextEntry(Id(:object_name), _("DHCP Server object name"), object_name),
          VSpacing(1.0),
          Left(
            Frame(
              _("Common DHCP Configuration Object Contexts"),
              MarginBox(
                1.5,
                0.2,
                VBox(
                  HBox(
                    TextEntry(
                      Id(:locator_context),
                      _("Locator context (e.g. ou=dhcp,o=microfocus)"),
                      locator_context
                    ),
                    VBox(Label(""), PushButton(Id(:rtvBttn), _("&Retrieve")))
                  ),
                  TextEntry(
                    Id(:group_context),
                    _("Group context (e.g. ou=dhcp,o=microfocus)"),
                    group_context
                  )
                )
              )
            )
          ),
          VSpacing(1.0),
          Left(
            MinWidth(
              45,
              HBox(
                TextEntry(
                  Id(:debug_path),
                  Opt(:hstretch),
                  _("Log file location"),
                  debug_path
                ),
                VBox(Label(""), PushButton(Id(:browse), _("Browse")))
              )
            )
          ),
          VSpacing(1.0),
          Left(
            HBox(
              Frame(
                _("LDAP method"),
                MarginBox(
                  1.5,
                  0.2,
                  RadioButtonGroup(
                    Id(:rb),
                    VBox(
                      Left(RadioButton(Id(0), _("Static"))),
                      Left(RadioButton(Id(1), _("Dynamic")))
                    )
                  )
                )
              ),
              HSpacing(2.0),
              Frame(
                _("Referrals"),
                MarginBox(
                  1.5,
                  0.2,
                  RadioButtonGroup(
                    Id(:rb1),
                    VBox(
                      Left(RadioButton(Id(2), _("Chase referral"))),
                      Left(RadioButton(Id(3), _("Do not chase referral")))
                    )
                  )
                )
              )
            )
          ),
          VSpacing(1.0)
        )
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "configure_dhcp1", ""),
        Label.BackButton,
        Label.NextButton
      )
      UI.SetFocus(Id(:next))

      if ndsTreeType == "new"
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, false)
      else
        UI.ChangeWidget(Id(:rtvBttn), :Enabled, true)
      end

      if ldap_method == "dynamic"
        UI.ChangeWidget(Id(:rb), :CurrentButton, 1)
      else
        UI.ChangeWidget(Id(:rb), :CurrentButton, 0)
      end

      if chase_referrals == "yes"
        UI.ChangeWidget(Id(:rb1), :CurrentButton, 2)
      else
        UI.ChangeWidget(Id(:rb1), :CurrentButton, 3)
      end

      PromptIfNeededForEdirAdminPassword()

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          server_context = Convert.to_string(
            UI.QueryWidget(Id(:server_context), :Value)
          )
          next if !NovellValidators.ValidateContext(server_context)

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_SERVER_CONTEXT",
            NovellUtils.Nds2Ldap(server_context)
          )

          locator_context = Convert.to_string(
            UI.QueryWidget(Id(:locator_context), :Value)
          )
          next if !NovellValidators.ValidateContext(locator_context)

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LOCATOR_CONTEXT",
            NovellUtils.Nds2Ldap(locator_context)
          )

          group_context = Convert.to_string(
            UI.QueryWidget(Id(:group_context), :Value)
          )
          next if !NovellValidators.ValidateContext(group_context)

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_GROUP_CONTEXT",
            NovellUtils.Nds2Ldap(group_context)
          )

          object_name = Convert.to_string(
            UI.QueryWidget(Id(:object_name), :Value)
          )

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_SERVER_OBJECT_NAME",
            object_name
          )

          debug_path = Convert.to_string(
            UI.QueryWidget(Id(:debug_path), :Value)
          )

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LDAP_DEBUGFILE",
            debug_path
          )

          if Convert.to_integer(UI.QueryWidget(Id(:rb), :CurrentButton)) == 0
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_LDAP_METHOD", "static")
          else
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_METHOD",
              "dynamic"
            )
          end

          if Convert.to_integer(UI.QueryWidget(Id(:rb1), :CurrentButton)) == 0
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_LDAP_REFERRALS", "yes")
          else
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_LDAP_REFERRALS", "no")
          end

          break
        elsif ret == :rtvBttn
          # Try to get the context information.
          contextInfo = NovellDhcp.GetContextInfo
          if contextInfo == nil
            Popup.Message(
              _(
                "The locator and group object could not be obtained by searching the tree.\nEnter the object contexts manually."
              )
            )
          else
            UI.ChangeWidget(
              Id(:locator_context),
              :Value,
              Ops.get(contextInfo, 0, "")
            )
            UI.ChangeWidget(
              Id(:group_context),
              :Value,
              Ops.get(contextInfo, 1, "")
            )
          end
          next
        elsif ret == :browse
          debugPath = Convert.to_string(UI.QueryWidget(Id(:debug_path), :Value))
          debugPath = UI.AskForExistingFile(
            debugPath,
            "",
            _("OES DHCP Services Debug File")
          )
          UI.ChangeWidget(Id(:debug_path), :Value, debugPath)
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    # NovelldhcpCert dialog
    # @return dialog result
    def NovelldhcpCertDialog
      # Novell DHCP Services cert dialog caption
      caption = _("OES DHCP LDAP and Secure Channel Configuration")

      ldap_server = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_SERVER",
        ""
      )
      if ldap_server == nil || !NovellLDAP.AddressExists(ldap_server, nil)
        ldap_server = ""
      end

      ldap_user = NovellUtils.Nds2Ldap(
        Ops.get_string(
          NovellDhcp.Settings,
          "CONFIG_DHCPSRV_LDAP_USER_CONTEXT",
          ""
        )
      )
      ldap_user_password = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_USER_PASSWORD",
        ""
      )
      use_secure_port = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_USE_SECURE_PORT",
        ""
      )
      use_secure_port_config = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_USE_SECURE_PORT_FOR_CONFIG",
        ""
      )
      server_list = Ops.get_list(
        NovellLDAP.Settings,
        "CONFIG_LDAP_SERVERS_LIST",
        []
      )
      reqcert = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_CHECK_METHOD",
        ""
      )
      ca_cert = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_CERTIFICATE_AUTHORITY",
        ""
      )
      client_cert = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_CLIENT_CERTIFICATE",
        ""
      )
      client_key = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_CLIENT_KEY",
        ""
      )
      dhcp_ldap_port = Ops.get_integer(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_LDAP_PORT",
        -1
      )
      server_list_widget = NovellLDAPUI.ServerListWidget(
        server_list,
        _("eDirectory server address or host name"),
        ldap_server,
        true,
        :combo
      )
      ldap_widget = Ops.get_term(server_list_widget, "term") { VBox(:Empty) }

      commonProxyName = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCP_COMMON_PROXY",
        ""
      )
      commonProxyPassword = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCP_COMMON_PROXY_PASSWORD",
        ""
      )

      contents = HVSquash(
        VBox(
          ldap_widget,
          Left(
            CheckBox(
              Id(:use_secure_port_conf),
              Opt(:notify),
              _("Use secure channel for configuration")
            )
          ),
          MultiLineEdit(
            Id(:ldap_user),
            _("Proxy User for DHCP Management"),
            ldap_user
          ),
          Left(
            HVSquash(
              IntField(
                Id(:dhcpLdapPort),
                _("LDAP port for DHCP server (e.g. 636):"),
                0,
                65535,
                dhcp_ldap_port
              )
            )
          ),
          Left(
            CheckBox(
              Id(:use_secure_port),
              Opt(:notify),
              _("Use secure channel for DHCP server")
            )
          ),
          Frame(
            _("Certificates (optional)"),
            VBox(
              ComboBox(
                Id(:reqcert_c),
                Opt(:hstretch, :notify),
                _("&Request Certificate"),
                [
                  Item(Id(:reqcert_never), _("Never")),
                  Item(Id(:reqcert_allow), _("Allow")),
                  Item(Id(:reqcert_try), _("Try")),
                  Item(Id(:reqcert_hard), _("Hard")),
                  Item(Id(:empty), "")
                ]
              ),
              HBox(
                TextEntry(
                  Id(:ca_cert),
                  _("LDAP CA file (e.g./etc/opt/novell/certs/ca.pem):"),
                  ca_cert
                ),
                VBox(Label(""), PushButton(Id(:browse_ca_cert), _("Browse")))
              ),
              HBox(
                TextEntry(
                  Id(:client_cert),
                  _(
                    "LDAP client certificate (e.g./etc/opt/novell/certs/cert.pem):"
                  ),
                  client_cert
                ),
                VBox(
                  Label(""),
                  PushButton(Id(:browse_client_cert), _("Browse"))
                )
              ),
              HBox(
                TextEntry(
                  Id(:client_key),
                  _(
                    "LDAP client Key file (e.g./etc/opt/novell/certs/cert.pem):"
                  ),
                  client_key
                ),
                VBox(Label(""), PushButton(Id(:browse_client_key), _("Browse")))
              )
            )
          )
        )
      )

      helps = Ops.add(
        Ops.get_string(@HELPS, "configure_dhcp2_title", ""),
        Ops.add(
          Ops.get_string(server_list_widget, "helps", ""),
          Ops.get_string(@HELPS, "configure_dhcp2", "")
        )
      )
      Wizard.SetContentsButtons(
        caption,
        contents,
        helps,
        Label.BackButton,
        Label.NextButton
      )

      UI.SetFocus(Id(:next))

      dflt = nil
      if reqcert == "allow"
        dflt = :reqcert_allow
      elsif reqcert == "try"
        dflt = :reqcert_try
      elsif reqcert == "hard"
        dflt = :reqcert_hard
      else
        dflt = :reqcert_never
      end

      UI.ChangeWidget(Id(:ldap_user), :Enabled, false)
      UI.ChangeWidget(Id(:reqcert_c), :Value, dflt)

      if use_secure_port != "no"
        UI.ChangeWidget(Id(:use_secure_port), :Value, true)
        UI.ChangeWidget(Id(:reqcert_c), :Enabled, true)
        UI.ChangeWidget(Id(:ca_cert), :Enabled, true)
        UI.ChangeWidget(Id(:browse_ca_cert), :Enabled, true)
        UI.ChangeWidget(Id(:client_cert), :Enabled, true)
        UI.ChangeWidget(Id(:browse_client_cert), :Enabled, true)
        UI.ChangeWidget(Id(:client_key), :Enabled, true)
        UI.ChangeWidget(Id(:browse_client_key), :Enabled, true)
      else
        UI.ChangeWidget(Id(:use_secure_port), :Value, false)
        UI.ChangeWidget(Id(:reqcert_c), :Enabled, false)
        UI.ChangeWidget(Id(:ca_cert), :Enabled, false)
        UI.ChangeWidget(Id(:browse_ca_cert), :Enabled, false)
        UI.ChangeWidget(Id(:client_cert), :Enabled, false)
        UI.ChangeWidget(Id(:browse_client_cert), :Enabled, false)
        UI.ChangeWidget(Id(:client_key), :Enabled, false)
        UI.ChangeWidget(Id(:browse_client_key), :Enabled, false)
      end

      if use_secure_port_config != "no"
        UI.ChangeWidget(Id(:use_secure_port_conf), :Value, true)
      else
        UI.ChangeWidget(Id(:use_secure_port_conf), :Value, false)
      end

      PromptIfNeededForEdirAdminPassword()

      full_admin_context = NovellUtils.Nds2Ldap(
        Ops.get_string(NovellLDAP.Settings, "CONFIG_LDAP_ADMIN_CONTEXT", "")
      )
      admin_pwd = Ops.get_string(
        NovellLDAP.Settings,
        "CONFIG_LDAP_ADMIN_PASSWORD",
        ""
      )
      if NovellDhcp.xadMode
        xad_tree_admin_context = Ops.get_string(
          NovellLDAP.Settings,
          "XAD_TREE_ADMIN_CONTEXT",
          ""
        )
        Builtins.y2milestone(
          "NovellDhcp:XAD_TREE_ADMIN_CONTEXT:%1",
          xad_tree_admin_context
        )
        if xad_tree_admin_context != nil && xad_tree_admin_context != ""
          full_admin_context = NovellUtils.Nds2Ldap(xad_tree_admin_context)
          admin_pwd = Ops.get_string(
            NovellLDAP.Settings,
            "XAD_TREE_ADMIN_PASSWORD",
            ""
          )
        end
      end

      if NovellUtils.Nds2Ldap(ldap_user) == full_admin_context &&
          ldap_user_password == ""
        ldap_user_password = admin_pwd
      end

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          ldap_server = Convert.to_string(
            UI.QueryWidget(Id(:server_select), :Value)
          )
          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LDAP_SERVER",
            ldap_server
          )

          if !NovellValidators.ValidateFDN(ldap_user, false)
            name = ldap_user
            name = NovellUtils.Strip(name, " ")
            if name == nil || name == "" || name == " "
              Popup.Error(_("A valid LDAP user must be entered."))
            end
            next
          end

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LDAP_USER_CONTEXT",
            ldap_user
          )

          next if !NovellValidators.ValidatePassword(ldap_user_password)

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LDAP_USER_PASSWORD",
            ldap_user_password
          )

          if Convert.to_boolean(UI.QueryWidget(Id(:use_secure_port), :Value))
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_USE_SECURE_PORT",
              "yes"
            )
            type = nil
            type = Convert.to_symbol(UI.QueryWidget(Id(:reqcert_c), :Value))
            if type == :reqcert_allow
              reqcert = "allow"
            elsif type == :reqcert_try
              reqcert = "try"
            elsif type == :reqcert_hard
              reqcert = "hard"
            else
              reqcert = "never"
            end

            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CHECK_METHOD",
              reqcert
            )

            ca_cert = Convert.to_string(UI.QueryWidget(Id(:ca_cert), :Value))
            client_cert = Convert.to_string(
              UI.QueryWidget(Id(:client_cert), :Value)
            )
            client_key = Convert.to_string(
              UI.QueryWidget(Id(:client_key), :Value)
            )
            if reqcert == "hard" || reqcert == "try"
              if ca_cert == nil || ca_cert == ""
                Popup.Error(
                  _(
                    "LDAP CA file does not exist. A valid path and file name must be entered."
                  )
                )
                next
              end
              if client_cert == nil || client_cert == ""
                Popup.Error(
                  _(
                    "Client certificate file does not exist. A valid path and file name must be entered."
                  )
                )
                next
              end
              if client_key == nil || client_key == ""
                Popup.Error(
                  _(
                    "Client key file does not exist. A valid path and file name must be entered."
                  )
                )
                next
              end
            end
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CERTIFICATE_AUTHORITY",
              ca_cert
            )
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CLIENT_CERTIFICATE",
              client_cert
            )
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CLIENT_KEY",
              client_key
            )
          else
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_USE_SECURE_PORT", "no")
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_LDAP_CHECK_METHOD", "")
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CERTIFICATE_AUTHORITY",
              ""
            )
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_LDAP_CLIENT_CERTIFICATE",
              ""
            )
            Ops.set(NovellDhcp.Settings, "CONFIG_DHCPSRV_LDAP_CLIENT_KEY", "")
          end

          if Convert.to_boolean(
              UI.QueryWidget(Id(:use_secure_port_conf), :Value)
            )
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_USE_SECURE_PORT_FOR_CONFIG",
              "yes"
            )
          else
            Ops.set(
              NovellDhcp.Settings,
              "CONFIG_DHCPSRV_USE_SECURE_PORT_FOR_CONFIG",
              "no"
            )
          end

          dhcp_ldap_port = Convert.to_integer(
            UI.QueryWidget(Id(:dhcpLdapPort), :Value)
          )
          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_LDAP_PORT",
            dhcp_ldap_port
          )

          break
        elsif ret == :use_secure_port
          if Convert.to_boolean(UI.QueryWidget(Id(:use_secure_port), :Value))
            UI.ChangeWidget(Id(:reqcert_c), :Enabled, true)
            UI.ChangeWidget(Id(:ca_cert), :Enabled, true)
            UI.ChangeWidget(Id(:browse_ca_cert), :Enabled, true)
            UI.ChangeWidget(Id(:client_cert), :Enabled, true)
            UI.ChangeWidget(Id(:browse_client_cert), :Enabled, true)
            UI.ChangeWidget(Id(:client_key), :Enabled, true)
            UI.ChangeWidget(Id(:browse_client_key), :Enabled, true)
          else
            UI.ChangeWidget(Id(:reqcert_c), :Enabled, false)
            UI.ChangeWidget(Id(:ca_cert), :Enabled, false)
            UI.ChangeWidget(Id(:browse_ca_cert), :Enabled, false)
            UI.ChangeWidget(Id(:client_cert), :Enabled, false)
            UI.ChangeWidget(Id(:browse_client_cert), :Enabled, false)
            UI.ChangeWidget(Id(:client_key), :Enabled, false)
            UI.ChangeWidget(Id(:browse_client_key), :Enabled, false)
          end
          next
        elsif ret == :browse_ca_cert
          caCert = Convert.to_string(UI.QueryWidget(Id(:ca_cert), :Value))
          caCert = UI.AskForExistingFile(caCert, "", _("LDAP CA file:"))
          UI.ChangeWidget(Id(:ca_cert), :Value, caCert)
        elsif ret == :browse_client_cert
          clientCert = Convert.to_string(
            UI.QueryWidget(Id(:client_cert), :Value)
          )
          clientCert = UI.AskForExistingFile(
            clientCert,
            "",
            _("LDAP client certificate:")
          )
          UI.ChangeWidget(Id(:client_cert), :Value, clientCert)
        elsif ret == :browse_client_key
          clientKey = Convert.to_string(UI.QueryWidget(Id(:client_key), :Value))
          clientKey = UI.AskForExistingFile(
            clientKey,
            "",
            _("LDAP client Key file:")
          )
          UI.ChangeWidget(Id(:client_key), :Value, clientKey)
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end

    def InitializeInterfaces
      NetworkInterfaces.Read

      Builtins.foreach(NetworkInterfaces.List("")) do |iface|
        if iface != "" && !Builtins.issubstring(iface, "lo") &&
            !Builtins.issubstring(iface, "sit")
          device_name = NetworkInterfaces.GetValue(iface, "NAME")
          if Ops.greater_than(Builtins.size(device_name), 40)
            device_name = Ops.add(Builtins.substring(device_name, 0, 37), "...")
          end

          Ops.set(
            NovellDhcp.ifaces,
            iface,
            {
              "device" => device_name,
              "ipaddr" => NetworkInterfaces.GetValue(iface, "BOOTPROTO") == "dhcp" ?
                _("DHCP address") :
                Address.Check4(NetworkInterfaces.GetValue(iface, "IPADDR")) ?
                  NetworkInterfaces.GetValue(iface, "IPADDR") :
                  "",
              "active" => false
            }
          )
        end
      end

      nil
    end

    def SetInterfacesTableButtons
      current_item = Convert.to_string(
        UI.QueryWidget(Id("nic_selection"), :CurrentItem)
      )

      # The currently selected item is active, can be deactivated
      if Ops.get_boolean(NovellDhcp.ifaces, [current_item, "active"]) == true
        UI.ChangeWidget(Id(:addCard), :Enabled, false)
        UI.ChangeWidget(Id(:removeCard), :Enabled, true) 
        # and vice versa
      else
        UI.ChangeWidget(Id(:addCard), :Enabled, true)
        UI.ChangeWidget(Id(:removeCard), :Enabled, false)
      end

      nil
    end

    def RedrawInterfacesTable
      table_items = []
      Builtins.foreach(NovellDhcp.ifaces) do |iface, settings|
        table_items = Builtins.add(
          table_items,
          Item(
            Id(iface),
            Ops.get_boolean(settings, "active", false) ? "x" : "",
            iface,
            Ops.get_string(settings, "device", ""),
            Ops.get_string(settings, "ipaddr", "")
          )
        )
      end

      UI.ChangeWidget(Id("nic_selection"), :Items, table_items)
      if @current_item_iface != nil
        UI.ChangeWidget(Id("nic_selection"), :CurrentItem, @current_item_iface)
      end
      SetInterfacesTableButtons()

      nil
    end

    def ValidateInterfaces
      allowed_interfaces = []
      configured_interfaces = []
      Builtins.foreach(NovellDhcp.ifaces) do |iface, settings|
        if Ops.get_boolean(NovellDhcp.ifaces, [iface, "active"], false) == true
          allowed_interfaces = Builtins.add(allowed_interfaces, iface)
          raise Break
        end
      end
      if Ops.less_or_equal(Builtins.size(allowed_interfaces), 0)
        Report.Error(_("At least one network interface must be selected."))
        return false
      end
      true
    end

    def GetSelectedInterfaces
      interfaces = ""

      Builtins.foreach(NovellDhcp.ifaces) do |iface, settings|
        if Ops.get_boolean(NovellDhcp.ifaces, [iface, "active"], false) == true
          if interfaces == ""
            interfaces = iface
          else
            interfaces = Ops.add(Ops.add(interfaces, " "), iface)
          end
        end
      end

      interfaces
    end

    def SetSelectedInterfaces
      interfaces = ""

      # First get the saved interfaces from the /etc/sysconfig/novell/NovellDhcp file..
      confFileValue = Ops.get_string(
        NovellDhcp.Settings,
        "CONFIG_DHCPSRV_INTERFACES",
        ""
      )
      split = Builtins.splitstring(confFileValue, " ") # Get individual interface values.

      Builtins.foreach(NovellDhcp.ifaces) do |iface, settings|
        Builtins.foreach(split) do |card|
          if card == iface
            Ops.set(NovellDhcp.ifaces, [iface, "active"], true)
            raise Break
          end
        end
      end if split != nil &&
        split != []

      nil
    end

    # NovelldhcpCardSelectDialog dialog
    # @return dialog result
    def NovelldhcpCardSelectDialog
      # Novell DHCP Services configure2 dialog caption
      caption = _("OES DHCP Services Interface Selection")

      InitializeInterfaces()

      contents = VBox(
        VSpacing(1),
        VBox(
          VBox(
            # Table - listing available network cards
            Left(Label(_("Network Boards for OES DHCP Server"))),
            Table(
              Id("nic_selection"),
              Opt(:notify, :immediate),
              Header(
                _("Selected"),
                _("Interface Name"),
                _("Device Name"),
                _("IP")
              ),
              []
            )
          ),
          HBox(
            PushButton(Id(:addCard), _("&Select")),
            PushButton(Id(:removeCard), _("&Deselect"))
          ),
          VStretch()
        ),
        VStretch()
      )

      Wizard.SetContentsButtons(
        caption,
        contents,
        Ops.get_string(@HELPS, "interfaces", ""),
        Label.BackButton,
        Label.NextButton
      )

      SetSelectedInterfaces()
      RedrawInterfacesTable()

      UI.SetFocus(Id(:next))

      ret = nil
      while true
        ret = UI.UserInput

        # abort?
        if ret == :abort || ret == :cancel
          if ReallyAbort()
            break
          else
            next
          end
        elsif ret == :next
          next if ValidateInterfaces() == false

          Ops.set(
            NovellDhcp.Settings,
            "CONFIG_DHCPSRV_INTERFACES",
            GetSelectedInterfaces()
          )
          break
        elsif ret == :addCard || ret == :removeCard
          item_id = Convert.to_string(
            UI.QueryWidget(Id("nic_selection"), :CurrentItem)
          )
          SetInterfacesTableButtons()
          @current_item_iface = item_id

          if ret == :addCard
            Ops.set(NovellDhcp.ifaces, [item_id, "active"], true)
          elsif ret == :removeCard
            Ops.set(NovellDhcp.ifaces, [item_id, "active"], false)
          end

          RedrawInterfacesTable()
          next
        elsif ret == "nic_selection"
          SetInterfacesTableButtons()
        elsif ret == :back
          break
        else
          Builtins.y2error("unexpected retcode: %1", ret)
          next
        end
      end
      deep_copy(ret)
    end
  end
end
