# encoding: utf-8

# ------------------------------------------------------------------------------
# Copyright (c) 2006 Novell, Inc. All Rights Reserved.
#
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of version 2 of the GNU General Public License as published by the
# Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, contact Novell, Inc.
#
# To contact Novell about this file by physical or electronic mail, you may find
# current contact information at www.novell.com.
# ------------------------------------------------------------------------------

# File:	include/novell-dhcp/wizards.ycp
# Package:	Configuration of novell-dhcp
# Summary:	Wizards definitions
# Authors:	Mark Clark <mclark@novell.com>
#
# $Id: wizards.ycp 27914 2006-02-13 14:32:08Z locilka $
module Yast
  module NovellDhcpWizardsInclude
    def initialize_novell_dhcp_wizards(include_target)
      Yast.import "UI"

      textdomain "novell-dhcp"

      Yast.import "Sequencer"
      Yast.import "Wizard"

      Yast.include include_target, "novell-dhcp/complex.rb"
      Yast.include include_target, "novell-dhcp/dialogs.rb"
    end

    # Main workflow of the dhcp configuration
    # @return sequence result
    def MainSequence
      aliases = {
        "dhcpinfo" => lambda { Novelldhcp2Dialog() },
        "certinfo" => lambda { NovelldhcpCertDialog() },
        "cardsel"  => lambda { NovelldhcpCardSelectDialog() }
      }


      sequence = {
        "ws_start" => "dhcpinfo",
        "dhcpinfo" => { :abort => :abort, :next => "certinfo", :skip => :next },
        "certinfo" => { :abort => :abort, :next => "cardsel" },
        "cardsel"  => { :abort => :abort, :next => :next }
      }

      ret = Sequencer.Run(aliases, sequence)

      deep_copy(ret)
    end

    # Whole configuration of dhcp
    # @return sequence result
    def NovellDhcpSequence
      aliases = {
        "read"  => [lambda { ReadDialog() }, true],
        "main"  => lambda { MainSequence() },
        "write" => [lambda { WriteDialog() }, true]
      }

      sequence = {
        "ws_start" => "read",
        "read"     => { :abort => :abort, :next => "main" },
        "main"     => { :abort => :abort, :next => "write" },
        "write"    => { :abort => :abort, :next => :next }
      }

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("novell-dhcp")

      ret = Sequencer.Run(aliases, sequence)

      UI.CloseDialog
      deep_copy(ret)
    end

    # Whole configuration of dhcp but without reading and writing.
    # For use with autoinstallation.
    # @return sequence result
    def NovellDhcpAutoSequence
      # Initialization dialog caption
      caption = _("DHCP Services Configuration")
      # Initialization dialog contents
      contents = Label(_("Initializing..."))

      Wizard.CreateDialog
      Wizard.SetDesktopIcon("novell-dhcp")
      Wizard.SetContentsButtons(
        caption,
        contents,
        "",
        Label.BackButton,
        Label.NextButton
      )

      ret = MainSequence()

      UI.CloseDialog
      deep_copy(ret)
    end
  end
end
